@@ -5,7 +5,7 @@ use crate::core::{
 use crate::{DMat3, DVec2, Mat3, Vec2};
 #[cfg(not(target_arch = "spirv"))]
 use core::fmt;
-use core::ops::{Add, Deref, DerefMut, Mul, Sub};
+use core::ops::{Add, AddAssign, Deref, DerefMut, Mul, MulAssign, Sub, SubAssign};
 
 #[cfg(all(
     target_arch = "x86",
@@ -24,7 +24,7 @@ use core::arch::x86_64::*;
 use std::iter::{Product, Sum};
 
 macro_rules! impl_mat2_methods {
-    ($t:ty, $vec2:ident, $inner:ident) => {
+    ($t:ty, $vec2:ident, $mat3:ident, $inner:ident) => {
         /// A 2x2 matrix with all elements set to `0.0`.
         pub const ZERO: Self = Self($inner::ZERO);
 
@@ -87,6 +87,12 @@ macro_rules! impl_mat2_methods {
             Self($inner::from_angle(angle))
         }
 
+        /// Creates a 2x2 matrix from a 3x3 matrix, discarding the 2nd row and column.
+        #[inline(always)]
+        pub fn from_mat3(m: $mat3) -> Self {
+            Self::from_cols(m.x_axis.into(), m.y_axis.into())
+        }
+
         /// Creates a 2x2 matrix from the first 4 values in `slice`.
         ///
         /// # Panics
@@ -117,10 +123,21 @@ macro_rules! impl_mat2_methods {
             match index {
                 0 => self.x_axis,
                 1 => self.y_axis,
-                _ => panic!(
-                    "index out of bounds: the len is 2 but the index is {}",
-                    index
-                ),
+                _ => panic!("index out of bounds"),
+            }
+        }
+
+        /// Returns a mutable reference to the matrix column for the given `index`.
+        ///
+        /// # Panics
+        ///
+        /// Panics if `index` is greater than 1.
+        #[inline]
+        pub fn col_mut(&mut self, index: usize) -> &mut $vec2 {
+            match index {
+                0 => &mut self.x_axis,
+                1 => &mut self.y_axis,
+                _ => panic!("index out of bounds"),
             }
         }
 
@@ -134,25 +151,10 @@ macro_rules! impl_mat2_methods {
             match index {
                 0 => $vec2::new(self.x_axis.x, self.y_axis.x),
                 1 => $vec2::new(self.x_axis.y, self.y_axis.y),
-                _ => panic!(
-                    "index out of bounds: the len is 2 but the index is {}",
-                    index
-                ),
+                _ => panic!("index out of bounds"),
             }
         }
 
-        // #[inline]
-        // pub(crate) fn col_mut(&mut self, index: usize) -> &mut $vec2 {
-        //     match index {
-        //         0 => unsafe { &mut *(self.0.as_mut().as_mut_ptr() as *mut $vec2) },
-        //         1 => unsafe { &mut *(self.0.as_mut()[2..].as_mut_ptr() as *mut $vec2) },
-        //         _ => panic!(
-        //             "index out of bounds: the len is 2 but the index is {}",
-        //             index
-        //         ),
-        //     }
-        // }
-
         /// Returns `true` if, and only if, all elements are finite.
         /// If any element is either `NaN`, positive or negative infinity, this will return `false`.
         #[inline]
@@ -183,6 +185,10 @@ macro_rules! impl_mat2_methods {
         /// Returns the inverse of `self`.
         ///
         /// If the matrix is not invertible the returned matrix will be invalid.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if the determinant of `self` is zero when `glam_assert` is enabled.
         #[must_use]
         #[inline(always)]
         pub fn inverse(&self) -> Self {
@@ -236,19 +242,14 @@ macro_rules! impl_mat2_methods {
 }
 
 macro_rules! impl_mat2_traits {
-    ($t:ty, $new:ident, $mat2:ident, $mat3:ident, $vec2:ident) => {
+    ($t:ty, $new:ident, $mat2:ident, $vec2:ident) => {
         /// Creates a 2x2 matrix from two column vectors.
         #[inline(always)]
         pub fn $new(x_axis: $vec2, y_axis: $vec2) -> $mat2 {
             $mat2::from_cols(x_axis, y_axis)
         }
 
-        impl Default for $mat2 {
-            #[inline(always)]
-            fn default() -> Self {
-                Self::IDENTITY
-            }
-        }
+        impl_matn_common_traits!($t, $mat2, $vec2);
 
         impl PartialEq for $mat2 {
             #[inline]
@@ -257,6 +258,7 @@ macro_rules! impl_mat2_traits {
             }
         }
 
+        #[cfg(not(target_arch = "spriv"))]
         impl AsRef<[$t; 4]> for $mat2 {
             #[inline(always)]
             fn as_ref(&self) -> &[$t; 4] {
@@ -264,6 +266,7 @@ macro_rules! impl_mat2_traits {
             }
         }
 
+        #[cfg(not(target_arch = "spriv"))]
         impl AsMut<[$t; 4]> for $mat2 {
             #[inline(always)]
             fn as_mut(&mut self) -> &mut [$t; 4] {
@@ -271,54 +274,6 @@ macro_rules! impl_mat2_traits {
             }
         }
 
-        impl Add<$mat2> for $mat2 {
-            type Output = Self;
-            #[inline(always)]
-            fn add(self, other: Self) -> Self {
-                Self(self.0.add_matrix(&other.0))
-            }
-        }
-
-        impl Sub<$mat2> for $mat2 {
-            type Output = Self;
-            #[inline(always)]
-            fn sub(self, other: Self) -> Self {
-                Self(self.0.sub_matrix(&other.0))
-            }
-        }
-
-        impl Mul<$mat2> for $mat2 {
-            type Output = Self;
-            #[inline(always)]
-            fn mul(self, other: Self) -> Self {
-                Self(self.0.mul_matrix(&other.0))
-            }
-        }
-
-        impl Mul<$vec2> for $mat2 {
-            type Output = $vec2;
-            #[inline(always)]
-            fn mul(self, other: $vec2) -> $vec2 {
-                $vec2(self.0.mul_vector(other.0))
-            }
-        }
-
-        impl Mul<$mat2> for $t {
-            type Output = $mat2;
-            #[inline(always)]
-            fn mul(self, other: $mat2) -> $mat2 {
-                $mat2(other.0.mul_scalar(self))
-            }
-        }
-
-        impl Mul<$t> for $mat2 {
-            type Output = Self;
-            #[inline(always)]
-            fn mul(self, other: $t) -> Self {
-                Self(self.0.mul_scalar(other))
-            }
-        }
-
         impl Deref for $mat2 {
             type Target = Columns2<$vec2>;
             #[inline(always)]
@@ -334,13 +289,6 @@ macro_rules! impl_mat2_traits {
             }
         }
 
-        impl From<$mat3> for $mat2 {
-            /// Creates a 2x2 matrix from the top left submatrix of the given 3x3 matrix.
-            fn from(m: $mat3) -> $mat2 {
-                $mat2::from_cols(m.x_axis.into(), m.y_axis.into())
-            }
-        }
-
         #[cfg(not(target_arch = "spirv"))]
         impl fmt::Debug for $mat2 {
             fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
@@ -357,26 +305,6 @@ macro_rules! impl_mat2_traits {
                 write!(f, "[{}, {}]", self.x_axis, self.y_axis)
             }
         }
-
-        #[cfg(feature = "std")]
-        impl<'a> Sum<&'a Self> for $mat2 {
-            fn sum<I>(iter: I) -> Self
-            where
-                I: Iterator<Item = &'a Self>,
-            {
-                iter.fold(Self::ZERO, |a, &b| Self::add(a, b))
-            }
-        }
-
-        #[cfg(feature = "std")]
-        impl<'a> Product<&'a Self> for $mat2 {
-            fn product<I>(iter: I) -> Self
-            where
-                I: Iterator<Item = &'a Self>,
-            {
-                iter.fold(Self::IDENTITY, |a, &b| Self::mul(a, b))
-            }
-        }
     };
 }
 
@@ -396,14 +324,14 @@ type InnerF32 = crate::core::storage::Columns2<XY<f32>>;
 pub struct Mat2(pub(crate) InnerF32);
 
 impl Mat2 {
-    impl_mat2_methods!(f32, Vec2, InnerF32);
+    impl_mat2_methods!(f32, Vec2, Mat3, InnerF32);
 
     #[inline(always)]
     pub fn as_f64(&self) -> DMat2 {
         DMat2::from_cols(self.x_axis.as_f64(), self.y_axis.as_f64())
     }
 }
-impl_mat2_traits!(f32, mat2, Mat2, Mat3, Vec2);
+impl_mat2_traits!(f32, mat2, Mat2, Vec2);
 
 type InnerF64 = crate::core::storage::Columns2<XY<f64>>;
 
@@ -413,18 +341,21 @@ type InnerF64 = crate::core::storage::Columns2<XY<f64>>;
 pub struct DMat2(pub(crate) InnerF64);
 
 impl DMat2 {
-    impl_mat2_methods!(f64, DVec2, InnerF64);
+    impl_mat2_methods!(f64, DVec2, DMat3, InnerF64);
 
     #[inline(always)]
     pub fn as_f32(&self) -> Mat2 {
         Mat2::from_cols(self.x_axis.as_f32(), self.y_axis.as_f32())
     }
 }
-impl_mat2_traits!(f64, dmat2, DMat2, DMat3, DVec2);
+impl_mat2_traits!(f64, dmat2, DMat2, DVec2);
 
 #[cfg(any(feature = "scalar-math", target_arch = "spriv"))]
 mod const_test_mat2 {
-    const_assert_eq!(4, core::mem::align_of::<super::Mat2>());
+    const_assert_eq!(
+        core::mem::align_of::<f32>(),
+        core::mem::align_of::<super::Mat2>()
+    );
     const_assert_eq!(16, core::mem::size_of::<super::Mat2>());
 }
 
@@ -435,6 +366,9 @@ mod const_test_mat2 {
 }
 
 mod const_test_dmat2 {
-    const_assert_eq!(8, core::mem::align_of::<super::DMat2>());
+    const_assert_eq!(
+        core::mem::align_of::<f64>(),
+        core::mem::align_of::<super::DMat2>()
+    );
     const_assert_eq!(32, core::mem::size_of::<super::DMat2>());
 }
