@@ -73,12 +73,6 @@ macro_rules! impl_quat_methods {
             Self(v.0)
         }
 
-        #[deprecated(since = "0.15.2", note = "Please use `from_slice()` instead")]
-        #[inline(always)]
-        pub fn from_slice_unaligned(slice: &[$t]) -> Self {
-            Self::from_slice(slice)
-        }
-
         /// Creates a rotation quaternion from a slice.
         ///
         /// # Preconditions
@@ -96,12 +90,6 @@ macro_rules! impl_quat_methods {
             Self(q)
         }
 
-        #[deprecated(since = "0.15.2", note = "Please use `write_to_slice()` instead")]
-        #[inline(always)]
-        pub fn write_to_slice_unaligned(self, slice: &mut [$t]) {
-            self.write_to_slice(slice)
-        }
-
         /// Writes the quaternion to an unaligned slice.
         ///
         /// # Panics
@@ -114,6 +102,10 @@ macro_rules! impl_quat_methods {
 
         /// Create a quaternion for a normalized rotation `axis` and `angle` (in radians).
         /// The axis must be normalized (unit-length).
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `axis` is not normalized when `glam_assert` is enabled.
         #[inline(always)]
         pub fn from_axis_angle(axis: $vec3, angle: $t) -> Self {
             Self($inner::from_axis_angle(axis.0, angle))
@@ -151,26 +143,12 @@ macro_rules! impl_quat_methods {
             Self($inner::from_rotation_z(angle))
         }
 
-        #[deprecated(
-            since = "0.15.0",
-            note = "Please use `from_euler(EulerRot::YXZ, yaw, pitch, roll)` instead"
-        )]
-        #[inline(always)]
-        pub fn from_rotation_ypr(yaw: $t, pitch: $t, roll: $t) -> Self {
-            Self::from_euler(EulerRot::YXZ, yaw, pitch, roll)
-        }
-
         #[inline(always)]
         /// Creates a quaternion from the given euler rotation sequence and the angles (in radians).
         pub fn from_euler(euler: EulerRot, a: $t, b: $t, c: $t) -> Self {
             euler.new_quat(a, b, c)
         }
 
-        #[deprecated(since = "0.15.0", note = "Please use `from_mat3` instead")]
-        pub fn from_rotation_mat3(mat: &$mat3) -> Self {
-            Self::from_mat3(mat)
-        }
-
         /// Creates a quaternion from a 3x3 rotation matrix.
         #[inline]
         pub fn from_mat3(mat: &$mat3) -> Self {
@@ -181,11 +159,6 @@ macro_rules! impl_quat_methods {
             ))
         }
 
-        #[deprecated(since = "0.15.0", note = "Please use `from_mat4` instead")]
-        pub fn from_rotation_mat4(mat: &$mat4) -> Self {
-            Self::from_mat4(mat)
-        }
-
         /// Creates a quaternion from a 3x3 rotation matrix inside a homogeneous 4x4 matrix.
         #[inline]
         pub fn from_mat4(mat: &$mat4) -> Self {
@@ -196,9 +169,8 @@ macro_rules! impl_quat_methods {
             ))
         }
 
-        /// Gets the minimal rotation for transforming `from` to `to`.
-        /// The rotation is in the plane spanned by the two vectors.
-        /// Will rotate at most 180 degrees.
+        /// Gets the minimal rotation for transforming `from` to `to`.  The rotation is in the
+        /// plane spanned by the two vectors.  Will rotate at most 180 degrees.
         ///
         /// The input vectors must be normalized (unit-length).
         ///
@@ -206,6 +178,10 @@ macro_rules! impl_quat_methods {
         ///
         /// For near-singular cases (from≈to and from≈-to) the current implementation
         /// is only accurate to about 0.001 (for `f32`).
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `from` or `to` are not normalized when `glam_assert` is enabled.
         #[cfg(feature = "std")]
         pub fn from_rotation_arc(from: $vec3, to: $vec3) -> Self {
             glam_assert!(from.is_normalized());
@@ -226,15 +202,19 @@ macro_rules! impl_quat_methods {
             }
         }
 
-        /// Gets the minimal rotation for transforming `from` to either `to` or `-to`.
-        /// This means that the resulting quaternion will rotate `from` so that it is colinear with `to`.
+        /// Gets the minimal rotation for transforming `from` to either `to` or `-to`.  This means
+        /// that the resulting quaternion will rotate `from` so that it is colinear with `to`.
         ///
-        /// The rotation is in the plane spanned by the two vectors.
-        /// Will rotate at most 90 degrees.
+        /// The rotation is in the plane spanned by the two vectors.  Will rotate at most 90
+        /// degrees.
         ///
         /// The input vectors must be normalized (unit-length).
         ///
         /// `to.dot(from_rotation_arc_colinear(from, to) * from).abs() ≈ 1`.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `from` or `to` are not normalized when `glam_assert` is enabled.
         #[cfg(feature = "std")]
         pub fn from_rotation_arc_colinear(from: $vec3, to: $vec3) -> Self {
             if from.dot(to) < 0.0 {
@@ -277,6 +257,10 @@ macro_rules! impl_quat_methods {
         /// Typically quaternion inverse returns the conjugate of a normalized quaternion.
         /// Because `self` is assumed to already be unit length this method *does not* normalize
         /// before returning the conjugate.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` is not normalized when `glam_assert` is enabled.
         #[must_use]
         #[inline(always)]
         pub fn inverse(self) -> Self {
@@ -319,6 +303,10 @@ macro_rules! impl_quat_methods {
         /// Returns `self` normalized to length 1.0.
         ///
         /// For valid results, `self` must _not_ be of length zero.
+        ///
+        /// Panics
+        ///
+        /// Will panic if `self` is zero length when `glam_assert` is enabled.
         #[must_use]
         #[inline(always)]
         pub fn normalize(self) -> Self {
@@ -354,6 +342,10 @@ macro_rules! impl_quat_methods {
         /// for transforming this quaternion into another.
         ///
         /// Both quaternions must be normalized.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` or `other` are not normalized when `glam_assert` is enabled.
         pub fn angle_between(self, other: Self) -> $t {
             glam_assert!(self.is_normalized() && other.is_normalized());
             use crate::core::traits::scalar::FloatEx;
@@ -379,6 +371,10 @@ macro_rules! impl_quat_methods {
         ///
         /// When `s` is `0.0`, the result will be equal to `self`.  When `s`
         /// is `1.0`, the result will be equal to `other`.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` or `end` are not normalized when `glam_assert` is enabled.
         #[inline(always)]
         #[cfg_attr(docsrs, doc(alias = "mix"))]
         pub fn lerp(self, end: Self, s: $t) -> Self {
@@ -397,20 +393,33 @@ macro_rules! impl_quat_methods {
         /// one will take the short way. In order to correct for this, the `dot`
         /// product between `self` and `end` should be positive. If the `dot`
         /// product is negative, slerp between `-self` and `end`.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` or `end` are not normalized when `glam_assert` is enabled.
         #[inline(always)]
         pub fn slerp(self, end: Self, s: $t) -> Self {
             Self(self.0.slerp(end.0, s))
         }
 
         /// Multiplies a quaternion and a 3D vector, returning the rotated vector.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` is not normalized when `glam_assert` is enabled.
         #[inline(always)]
         pub fn mul_vec3(self, other: $vec3) -> $vec3 {
             $vec3(self.0.mul_vector3(other.0))
         }
 
-        /// Multiplies two quaternions.
-        /// If they each represent a rotation, the result will represent the combined rotation.
+        /// Multiplies two quaternions. If they each represent a rotation, the result will
+        /// represent the combined rotation.
+        ///
         /// Note that due to floating point rounding the result may not be perfectly normalized.
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `self` or `other` are not normalized when `glam_assert` is enabled.
         #[inline(always)]
         pub fn mul_quat(self, other: Self) -> Self {
             Self(self.0.mul_quaternion(other.0))
@@ -451,10 +460,11 @@ macro_rules! impl_quat_traits {
         impl Add<$quat> for $quat {
             type Output = Self;
             /// Adds two quaternions.
+            ///
             /// The sum is not guaranteed to be normalized.
             ///
-            /// NB: Addition is not the same as combining the rotations represented by the two quaternions!
-            /// That corresponds to multiplication.
+            /// Note that addition is not the same as combining the rotations represented by the
+            /// two quaternions! That corresponds to multiplication.
             #[inline]
             fn add(self, other: Self) -> Self {
                 Self(self.0.add(other.0))
@@ -464,6 +474,7 @@ macro_rules! impl_quat_traits {
         impl Sub<$quat> for $quat {
             type Output = Self;
             /// Subtracts the other quaternion from self.
+            ///
             /// The difference is not guaranteed to be normalized.
             #[inline]
             fn sub(self, other: Self) -> Self {
@@ -474,6 +485,7 @@ macro_rules! impl_quat_traits {
         impl Mul<$t> for $quat {
             type Output = Self;
             /// Multiplies a quaternion by a scalar value.
+            ///
             /// The product is not guaranteed to be normalized.
             #[inline]
             fn mul(self, other: $t) -> Self {
@@ -493,6 +505,15 @@ macro_rules! impl_quat_traits {
 
         impl Mul<$quat> for $quat {
             type Output = Self;
+            /// Multiplies two quaternions. If they each represent a rotation, the result will
+            /// represent the combined rotation.
+            ///
+            /// Note that due to floating point rounding the result may not be perfectly
+            /// normalized.
+            ///
+            /// # Panics
+            ///
+            /// Will panic if `self` or `other` are not normalized when `glam_assert` is enabled.
             #[inline]
             fn mul(self, other: Self) -> Self {
                 Self(self.0.mul_quaternion(other.0))
@@ -500,6 +521,15 @@ macro_rules! impl_quat_traits {
         }
 
         impl MulAssign<$quat> for $quat {
+            /// Multiplies two quaternions. If they each represent a rotation, the result will
+            /// represent the combined rotation.
+            ///
+            /// Note that due to floating point rounding the result may not be perfectly
+            /// normalized.
+            ///
+            /// # Panics
+            ///
+            /// Will panic if `self` or `other` are not normalized when `glam_assert` is enabled.
             #[inline]
             fn mul_assign(&mut self, other: Self) {
                 self.0 = self.0.mul_quaternion(other.0);
@@ -508,6 +538,11 @@ macro_rules! impl_quat_traits {
 
         impl Mul<$vec3> for $quat {
             type Output = $vec3;
+            /// Multiplies a quaternion and a 3D vector, returning the rotated vector.
+            ///
+            /// # Panics
+            ///
+            /// Will panic if `self` is not normalized when `glam_assert` is enabled.
             #[inline]
             fn mul(self, other: $vec3) -> Self::Output {
                 $vec3(self.0.mul_vector3(other.0))
@@ -536,6 +571,7 @@ macro_rules! impl_quat_traits {
             }
         }
 
+        #[cfg(not(target_arch = "spriv"))]
         impl AsRef<[$t; 4]> for $quat {
             #[inline(always)]
             fn as_ref(&self) -> &[$t; 4] {
@@ -543,6 +579,7 @@ macro_rules! impl_quat_traits {
             }
         }
 
+        #[cfg(not(target_arch = "spriv"))]
         impl AsMut<[$t; 4]> for $quat {
             #[inline(always)]
             fn as_mut(&mut self) -> &mut [$t; 4] {
@@ -699,7 +736,10 @@ impl_quat_traits!(f64, dquat, DQuat, DVec3, DVec4, InnerF64);
 
 #[cfg(any(feature = "scalar-math", target_arch = "spriv"))]
 mod const_test_quat {
-    const_assert_eq!(4, core::mem::align_of::<super::Quat>());
+    const_assert_eq!(
+        core::mem::align_of::<f32>(),
+        core::mem::align_of::<super::Quat>()
+    );
     const_assert_eq!(16, core::mem::size_of::<super::Quat>());
 }
 
@@ -710,6 +750,9 @@ mod const_test_quat {
 }
 
 mod const_test_dquat {
-    const_assert_eq!(8, core::mem::align_of::<super::DQuat>());
+    const_assert_eq!(
+        core::mem::align_of::<f64>(),
+        core::mem::align_of::<super::DQuat>()
+    );
     const_assert_eq!(32, core::mem::size_of::<super::DQuat>());
 }
